@@ -147,6 +147,9 @@ def sdist_expected_correct_file_structure():
         # 'src/stubs/requests_futures/sessions.pyi',
     )
     TESTS = (
+        'tests/test_git_sdk.py',
+        'tests/test_git_porcelain.py',
+        'tests/test_is_repo_clean_function.py',
         'tests/biskotaki_ci/conftest.py',
         'tests/test_load_util.py',
         'tests/biskotaki_ci/snapshot/biskotaki_ci_no_input/test_build_creates_artifacts.py',
